"""Astropy Sphinx Theme"""

from pathlib import Path

from pydata_sphinx_theme import utils


def get_html_theme_path():
    return Path(__file__).resolve().parent / "astropy-unified"


def update_config(app) -> None:
    # Here we default some config options (i.e. things in conf.py) unless they are set by the user
    # Theme options are defaulted in theme.toml

    if not utils.config_provided_by_user(app, "html_logo"):
        app.config.html_logo = str(
            get_html_theme_path() / "static" / "img" / "astropy_logo_notext.svg"
        )

    if not utils.config_provided_by_user(app, "html_favicon"):
        app.config.html_favicon = str(get_html_theme_path() / "static" / "img" / "favicon.ico")


def setup(app):
    app.add_html_theme("astropy-unified", get_html_theme_path())
    app.add_css_file("css/astropy.css", priority=650)
    app.connect("builder-inited", update_config, priority=200)

    return {
        "parallel_read_safe": True,
        "parallel_write_safe": True,
    }



"""Astropy Sphinx Theme"""

from pathlib import Path


# This is kept for backwards compatibility reasons (see __init__.py)
def get_html_theme_path():
    return [str(Path(__file__).resolve().parent)]


def setup(app):
    app.add_html_theme(
        "bootstrap-astropy",
        Path(__file__).resolve().parent / "bootstrap-astropy",
    )

    return {
        "parallel_read_safe": False,
        "parallel_write_safe": False,
    }



import pytest
from packaging.version import Version
from sphinx import __version__

SPHINX_LT_17 = Version(__version__) < Version("1.7")

if SPHINX_LT_17:
    from sphinx import build_main
else:
    from sphinx.cmd.build import build_main

THEMES = ["bootstrap-astropy"]


BASIC_CONF = """
source_suffix = '.rst'
master_doc = 'index'
html_theme = '{theme}'
"""

BASIC_INDEX = """
Title
=====

Just a test
"""


@pytest.mark.parametrize("theme", THEMES)
def test_basic(tmpdir, theme):
    # Just make sure the docs build with the specified theme
    # (to make sure e.g. that no templates are missing)

    with open(tmpdir.join("conf.py").strpath, "w") as f:
        f.write(BASIC_CONF.format(theme=theme))

    with open(tmpdir.join("index.rst").strpath, "w") as f:
        f.write(BASIC_INDEX.format(theme=theme))

    src_dir = tmpdir.strpath
    html_dir = tmpdir.mkdir("html").strpath

    if SPHINX_LT_17:
        status = build_main(argv=["sphinx-build", "-W", "-b", "html", src_dir, html_dir])
    else:
        # As of Sphinx 1.7, the first argument is now no longer ignored
        status = build_main(argv=["-W", "-b", "html", src_dir, html_dir])

    assert status == 0



import warnings

from .bootstrap_astropy import get_html_theme_path as _old_theme_path


def get_html_theme_path():
    warnings.warn(
        "astropy_sphinx_theme.get_html_theme_path is deprecated, you shouldn't"
        " need to manually specify the theme path as the theme is registered with sphinx",
        DeprecationWarning,
        stacklevel=2,
    )
    return _old_theme_path()
